django-ichypd
=============

*I can has your personal details?* **django-ichypd** is a simple django app
that will allows you to show a form for a custom model that you provide and
saves data into this model. After that a confirmation is shown. It also ships
with some helpers for extracting this information as CSV to import it in your
favourite CRM system or newsletter app.

*ichypd* is pronounced like *egypt*.

Usage
-----

**django-ichypd** is in active development and still very young. Documentation
will follow if it proofs useful.
